grobnercrystals documentation — grobnercrystals 1.0 documentation

# grobnercrystals documentation

grobnercrystals is a SageMath package for working with Gröbner crystal structures.

Check out the Usage section for further information.

Note

This project is under active development.

## Contents

- Usage
  - Installation
  - Dependencies
  - References
- Examples
- Documentation
  - Permutations
    - `Perm`
      - `Perm.eff_reg()`
      - `Perm.levi_datum()`
  - Filtered RSK
    - `filtered_RSK()`
  - Crystal Operators on Matrices
    - `e()`
    - `f()`
  - Polynomial Rings
  - Ideals and Bicrystalline Tests
  - Interesting Classes of Ideals
  - Group Action Checks
    - `check_action()`